@@ -2,7 +2,7 @@
 /*
   makewam.php
   2004/12/2
-ǽ2005/7/25
+ǽ2005/9/14
 
 ԡͭ²ҥɥ֥졼
 δʿ
@@ -194,6 +194,9 @@ ryuhei@secondbrain.co.jp
         $title_contents .= 'products_model<>' . $products['products_model'] . ',';
         $title_contents .= 'products_isbn<>' . $products['products_isbn'] . ',';
         $title_contents .= 'products_image<>' . $products['products_image'];
+        $title_contents = str_replace("\r\n", "\r", $title_contents);
+        $title_contents = str_replace("\r", "\n", $title_contents);
+        $title_contents = str_replace("\n", "", $title_contents);
         fwrite($titledata, $title_contents . "\n");
       }
       fclose($indata);
@@ -518,61 +521,67 @@ ryuhei@secondbrain.co.jp
                 </table>
                 </td></tr>
 <?php
-      $m_inc_flg = false;
-      for($i = 0, $n = sizeof($mw_manufacturers_field); $i < $n; $i++) {
-        if ($mw_manufacturers_field[$i]['check'] == 1) {
-          $m_inc_flg = true;
+      if (KN_CFG_USE_MANUFACTURERS) {
+        $m_inc_flg = false;
+        for($i = 0, $n = sizeof($mw_manufacturers_field); $i < $n; $i++) {
+          if ($mw_manufacturers_field[$i]['check'] == 1) {
+            $m_inc_flg = true;
+          }
         }
-      }
-      echo '<tr><td colspan="2" class="main">' . tep_draw_checkbox_field('include_manufacturer_fields', '1', $m_inc_flg) . ' ' . TEXT_INCLUDES_MANUFACTURER_FIELDS . "</td></tr>\n";
+        echo '<tr><td colspan="2" class="main">' . tep_draw_checkbox_field('include_manufacturer_fields', '1', $m_inc_flg) . ' ' . TEXT_INCLUDES_MANUFACTURER_FIELDS . "</td></tr>\n";
 ?>
                 <tr><td width="20"><?php echo tep_draw_separator('pixel_trans.gif', '20', '10'); ?></td>
                 <td><table border="0" width="100%" cellspacing="5" cellpadding="3" class="knBox">
 <?php
-      for($i = 0, $n = sizeof($mw_manufacturers_field); $i < $n; $i++) {
-        switch ($mw_manufacturers_field[$i]['check']) {
-          case 0:
-            echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_manufacturers_field[$i]['field'], '1', false) . '</td><td class="knMenu">' . $mw_manufacturers_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_manufacturers_field[$i]['field'] . '_weight', $mw_manufacturers_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
-            break;
-          case 1:
-            echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_manufacturers_field[$i]['field'], '1', true) . '</td><td class="knMenu">' . $mw_manufacturers_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_manufacturers_field[$i]['field'] . '_weight', $mw_manufacturers_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
-            break;
-          case 9:
-            echo '                  <tr><td width="20">' . tep_draw_hidden_field($mw_manufacturers_field[$i]['field'], '9') . '</td><td class="knMenu">' . $mw_manufacturers_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_manufacturers_field[$i]['field'] . '_weight', $mw_manufacturers_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
-            break;
+        for($i = 0, $n = sizeof($mw_manufacturers_field); $i < $n; $i++) {
+          switch ($mw_manufacturers_field[$i]['check']) {
+            case 0:
+              echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_manufacturers_field[$i]['field'], '1', false) . '</td><td class="knMenu">' . $mw_manufacturers_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_manufacturers_field[$i]['field'] . '_weight', $mw_manufacturers_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
+              break;
+            case 1:
+              echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_manufacturers_field[$i]['field'], '1', true) . '</td><td class="knMenu">' . $mw_manufacturers_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_manufacturers_field[$i]['field'] . '_weight', $mw_manufacturers_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
+              break;
+            case 9:
+              echo '                  <tr><td width="20">' . tep_draw_hidden_field($mw_manufacturers_field[$i]['field'], '9') . '</td><td class="knMenu">' . $mw_manufacturers_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_manufacturers_field[$i]['field'] . '_weight', $mw_manufacturers_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
+              break;
+          }
         }
-      }
 ?>
                 </table>
                 </td></tr>
 <?php
-      $r_inc_flg = false;
-      for($i = 0, $n = sizeof($mw_reviews_field); $i < $n; $i++) {
-        if ($mw_reviews_field[$i]['check'] == 1) {
-          $r_inc_flg = true;
-        }
       }
-      echo '<tr><td colspan="2" class="main">' . tep_draw_checkbox_field('include_review_fields', '1', $r_inc_flg) . ' ' . TEXT_INCLUDES_REVIEW_FIELDS . "</td></tr>\n";
+      if (KN_CFG_USE_REVIEWS == 'true') {
+        $r_inc_flg = false;
+        for($i = 0, $n = sizeof($mw_reviews_field); $i < $n; $i++) {
+          if ($mw_reviews_field[$i]['check'] == 1) {
+            $r_inc_flg = true;
+          }
+        }
+        echo '<tr><td colspan="2" class="main">' . tep_draw_checkbox_field('include_review_fields', '1', $r_inc_flg) . ' ' . TEXT_INCLUDES_REVIEW_FIELDS . "</td></tr>\n";
 ?>
                 <tr><td width="20"><?php echo tep_draw_separator('pixel_trans.gif', '20', '10'); ?></td>
                 <td><table border="0" width="100%" cellspacing="5" cellpadding="3" class="knBox">
 <?php
-      for($i = 0, $n = sizeof($mw_reviews_field); $i < $n; $i++) {
-        switch ($mw_reviews_field[$i]['check']) {
-          case 0:
-            echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_reviews_field[$i]['field'], '1', false) . '</td><td class="knMenu">' . $mw_reviews_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_reviews_field[$i]['field'] . '_weight', $mw_reviews_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
-            break;
-          case 1:
-            echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_reviews_field[$i]['field'], '1', true) . '</td><td class="knMenu">' . $mw_reviews_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_reviews_field[$i]['field'] . '_weight', $mw_reviews_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
-            break;
-          case 9:
-            echo '                  <tr><td width="20">' . tep_draw_hidden_field($mw_reviews_field[$i]['field'], '9') . '</td><td class="knMenu">' . $mw_reviews_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_reviews_field[$i]['field'] . '_weight', $mw_reviews_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
-            break;
+        for($i = 0, $n = sizeof($mw_reviews_field); $i < $n; $i++) {
+          switch ($mw_reviews_field[$i]['check']) {
+            case 0:
+              echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_reviews_field[$i]['field'], '1', false) . '</td><td class="knMenu">' . $mw_reviews_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_reviews_field[$i]['field'] . '_weight', $mw_reviews_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
+              break;
+            case 1:
+              echo '                  <tr><td width="20">' . tep_draw_checkbox_field($mw_reviews_field[$i]['field'], '1', true) . '</td><td class="knMenu">' . $mw_reviews_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_reviews_field[$i]['field'] . '_weight', $mw_reviews_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
+              break;
+            case 9:
+              echo '                  <tr><td width="20">' . tep_draw_hidden_field($mw_reviews_field[$i]['field'], '9') . '</td><td class="knMenu">' . $mw_reviews_field[$i]['title'] . '</td><td align="right" class="knMenu">' . tep_draw_input_field($mw_reviews_field[$i]['field'] . '_weight', $mw_reviews_field[$i]['weight'], 'size="3"') . "</td></tr>\n";
+              break;
+          }
         }
-      }
 ?>
                 </table>
                 </td></tr>
+<?php
+      }
+?>
               </table>
               <table border="0" width="100%" cellspacing="10" cellpadding="0">
                 <tr><td valign="top" class="main"><?php echo  tep_image_submit('button_update.gif', IMAGE_UPDATE); ?></td><td align="right"><?php echo '<a href="' . tep_href_link(FILENAME_MAKEWAM, 'action=products_wam_dump', 'NONSSL') . '" class="knInput">' . TEXT_PRODUCTS_WAM_DUMP_LINK . '</a>'; ?></td></tr>
