@@ -2,7 +2,7 @@
 /*
   products_edit.php
   2004/12/2
-ǽ2005/7/26
+ǽ2005/9/24
 
 ԡͭ²ҥɥ֥졼
 δʿ
@@ -458,6 +458,8 @@ ryuhei@secondbrain.co.jp
             $sql_data_array = tep_array_merge($sql_data_array, $insert_sql_data);
             tep_db_perform(TABLE_PRODUCTS, $sql_data_array);
             $products_id = tep_db_insert_id();
+            // products_modelư֤ϡproducts_id򥻥å
+            tep_db_query("update " . TABLE_PRODUCTS . " set products_model = '" . $products_id . "' where products_id = '" . $products_id . "'");
             // products_to_categoriesơ֥ɲ
             tep_db_query("insert into " . TABLE_PRODUCTS_TO_CATEGORIES . " (products_id, categories_id) values ('" . $products_id . "', '" . $categories_id . "')");
           } elseif ($HTTP_GET_VARS['action'] == 'update_product') {
@@ -668,7 +670,7 @@ ryuhei@secondbrain.co.jp
         <td><?php echo tep_draw_hidden_field('products_id', $pInfo->products_id); ?><table class="knEditTable">
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_PRODUCTS_MODEL; ?></td>
-            <td><?php echo tep_draw_input_field('products_model', $pInfo->products_model, '', false, 'text', false); ?></td>
+            <td><?php echo tep_draw_input_field('products_model', $pInfo->products_model, '', false, 'text', false) . ($HTTP_GET_VARS['action'] == 'new_product' ? '&nbsp;&nbsp;' . tep_draw_checkbox_field('p_model_auto_num', '1', true) . '&nbsp;&nbsp;' . TEXT_AUTO_NUM : ''); ?></td>
           </tr>
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_CATEGORIES; ?></td>
@@ -844,7 +846,7 @@ ryuhei@secondbrain.co.jp
           </tr>
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_SORT_ORDER; ?></td>
-            <td><?php echo tep_draw_input_field('sort_order', $pInfo->sort_order, '', false, 'text', false); ?></td>
+            <td><?php echo tep_draw_input_field('sort_order', $pInfo->sort_order, '', false, 'text', false) . ' ' . TEXT_SORT_ORDER_NOTE; ?></td>
           </tr>
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_PRODUCTS_MEMO; ?></td>
@@ -871,7 +873,7 @@ ryuhei@secondbrain.co.jp
         </table></td>
       </tr>
       <tr>
-        <td class="main"><?php echo tep_image_submit('button_preview.gif', IMAGE_PREVIEW) . '&nbsp;<a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>&nbsp;&nbsp;&nbsp;&nbsp;' . (KN_CFG_USE_REVIEWS == 'true' ? '<a href="' . tep_href_link(FILENAME_REVIEWS, 'pID=' . $pInfo->products_id) . '">' . tep_image_button('button_reviews.gif', IMAGE_REVIEWS) . '</a>&nbsp;' : '') . '<a href="' . tep_href_link(FILENAME_SPECIALS, 'specials_pID=' . $pInfo->products_id) . '">' . tep_image_button('button_specials.gif', IMAGE_SPECIALS) . '</a>'; ?></td>
+        <td class="main"><?php echo tep_image_submit('button_preview.gif', IMAGE_PREVIEW) . '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>' . ($HTTP_GET_VARS['action'] == 'edit_product' ? '&nbsp;&nbsp;&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT, 'action=delete_product_confirm&pID=' . $pInfo->products_id) . '">' . tep_image_button('button_delete.gif', IMAGE_DELETE) . '</a>' : '') . '&nbsp;&nbsp;' . (KN_CFG_USE_REVIEWS == 'true' ? '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_REVIEWS, 'pID=' . $pInfo->products_id) . '">' . tep_image_button('button_reviews.gif', IMAGE_REVIEWS) . '</a>' : '') . '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_SPECIALS, 'specials_pID=' . $pInfo->products_id) . '">' . tep_image_button('button_specials.gif', IMAGE_SPECIALS) . '</a>'; ?></td>
       </form></tr>
 <?php
       break;
@@ -889,7 +891,7 @@ ryuhei@secondbrain.co.jp
         <td><?php echo tep_draw_hidden_field('products_id', $HTTP_POST_VARS['products_id']) .  tep_draw_hidden_field('products_tax_class_id', $HTTP_POST_VARS['products_tax_class_id']); ?><table class="knEditTable" width="80%">
           <tr>
             <td class="knEditTableHeading" width="20%"><?php echo TEXT_PRODUCTS_MODEL; ?></td>
-            <td><?php echo $HTTP_POST_VARS['products_model'] . tep_draw_hidden_field('products_model', $HTTP_POST_VARS['products_model']); ?></td>
+            <td><?php echo ($HTTP_POST_VARS['p_model_auto_num'] ? TEXT_AUTO_NUM : $HTTP_POST_VARS['products_model']) . tep_draw_hidden_field('products_model', $HTTP_POST_VARS['products_model']) . tep_draw_hidden_field('categories_id', $HTTP_POST_VARS['p_model_auto_num']); ?></td>
           </tr>
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_CATEGORIES; ?></td>
@@ -939,6 +941,7 @@ ryuhei@secondbrain.co.jp
 <?php
       }
       if (KN_CFG_USE_KEYWORDS == "true") {
+        $HTTP_POST_VARS['products_keywords'] = str_replace("", " ", $HTTP_POST_VARS['products_keywords']);
 ?>
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_PRODUCTS_KEYWORDS; ?></td>
