@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: japanese.php,v 1.1.1.1 2005/06/30 05:04:17 ryu Exp $
+  $Id: japanese.php,v 1.2 2005/09/22 01:20:08 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -85,7 +85,7 @@ define('MALE_ADDRESS', ''); //Mr.
 define('FEMALE_ADDRESS', '');   //Ms.
 
 // text for date of birth example
-define('DOB_FORMAT_STRING', 'yyyy/mm/dd');
+define('DOB_FORMAT_STRING', 'yyyy-mm-dd');
 
 // geta_search box text in includes/boxes/geta_search.php
 define('BOX_HEADING_GETA_SEARCH', 'Ϣ۸');
